==> james-project-3.7.6-source-release.zip: james-project/server/protocols/webadmin/webadmin-jmap/src/main/java/org/apache/james/webadmin/data/jmap/PopulateEmailQueryViewRequestToTask.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.webadmin.data.jmap;

import static org.apache.james.webadmin.data.jmap.Constants.POPULATE_EMAIL_QUERY_VIEW;

import javax.inject.Inject;

import org.apache.james.webadmin.tasks.TaskFromRequestRegistry;

public class PopulateEmailQueryViewRequestToTask extends TaskFromRequestRegistry.TaskRegistration {
    @Inject
    PopulateEmailQueryViewRequestToTask(EmailQueryViewPopulator populator) {
        super(POPULATE_EMAIL_QUERY_VIEW,
            request -> new PopulateEmailQueryViewTask(populator, RunningOptionsParser.parse(request)));
    }
}

==> james-project-3.9.0-source-release.zip: james-project/server/protocols/webadmin/webadmin-jmap/src/main/java/org/apache/james/webadmin/data/jmap/PopulateEmailQueryViewRequestToTask.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.webadmin.data.jmap;

import static org.apache.james.webadmin.data.jmap.Constants.POPULATE_EMAIL_QUERY_VIEW;

import jakarta.inject.Inject;

import org.apache.james.webadmin.tasks.TaskFromRequestRegistry;

public class PopulateEmailQueryViewRequestToTask extends TaskFromRequestRegistry.TaskRegistration {
    @Inject
    PopulateEmailQueryViewRequestToTask(EmailQueryViewPopulator populator) {
        super(POPULATE_EMAIL_QUERY_VIEW,
            request -> new PopulateEmailQueryViewTask(populator, RunningOptionsParser.parse(request)));
    }
}
